@@ -47,5 +47,15 @@ fn bench_op_async(b: &mut Bencher) {
   bench_js_async(b, r#"Deno.core.opAsync("pi_async", null);"#, setup);
 }
 
-benchmark_group!(benches, bench_op_pi_json, bench_op_nop, bench_op_async);
+fn bench_is_proxy(b: &mut Bencher) {
+  bench_js_sync(b, r#"Deno.core.isProxy(42);"#, setup);
+}
+
+benchmark_group!(
+  benches,
+  bench_op_pi_json,
+  bench_op_nop,
+  bench_op_async,
+  bench_is_proxy
+);
 bench_or_profile!(benches);
